@@ -8,7 +8,7 @@ from tempor import ROOT_DIR, DATA_DIR
 from tempor.console import console
 
 
-def run_playbook(playbook="main.yml"):
+def run_playbook(playbook: str = "main.yml") -> None:
     ansible_data = f"{DATA_DIR}/ansible"
     if not os.path.exists(ansible_data):
         os.makedirs(ansible_data)
